@@ -34,7 +34,6 @@ import warnings
 warnings.filterwarnings("ignore", "Accessed deprecated property",
                         DeprecationWarning)
 
-import apt_pkg
 import distro_info
 import os
 import subprocess
@@ -407,7 +406,7 @@ class UpdateManager(Gtk.Window):
         # listening on dbus
         try:
             bus = dbus.SessionBus()
-        except Exception as e:
+        except Exception:
             print("warning: could not initiate dbus")
             return
         try:
@@ -445,7 +444,7 @@ class UpdateManagerDbusController(dbus.service.Object):
         try:
             self.parent.start_install()
             return True
-        except Exception as e:
+        except Exception:
             return False
 
     def _on_network_alert(self, watcher, state):
